# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/v1/room.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilibili.rpc import status_pb2 as bilibili_dot_rpc_dot_status__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n bilibili/broadcast/v1/room.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x19\x62ilibili/rpc/status.proto\x1a\x19google/protobuf/any.proto\"6\n\x0eRoomErrorEvent\x12$\n\x06status\x18\x01 \x01(\x0b\x32\x14.bilibili.rpc.Status\"\x0f\n\rRoomJoinEvent\"\x10\n\x0eRoomLeaveEvent\"K\n\x10RoomMessageEvent\x12\x13\n\x0btarget_path\x18\x01 \x01(\t\x12\"\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"5\n\x0fRoomOnlineEvent\x12\x0e\n\x06online\x18\x01 \x01(\x05\x12\x12\n\nall_online\x18\x02 \x01(\x05\"\xfe\x01\n\x07RoomReq\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x04join\x18\x02 \x01(\x0b\x32$.bilibili.broadcast.v1.RoomJoinEventH\x00\x12\x36\n\x05leave\x18\x03 \x01(\x0b\x32%.bilibili.broadcast.v1.RoomLeaveEventH\x00\x12\x38\n\x06online\x18\x04 \x01(\x0b\x32&.bilibili.broadcast.v1.RoomOnlineEventH\x00\x12\x36\n\x03msg\x18\x05 \x01(\x0b\x32\'.bilibili.broadcast.v1.RoomMessageEventH\x00\x42\x07\n\x05\x65vent\"\xb5\x02\n\x08RoomResp\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x04join\x18\x02 \x01(\x0b\x32$.bilibili.broadcast.v1.RoomJoinEventH\x00\x12\x36\n\x05leave\x18\x03 \x01(\x0b\x32%.bilibili.broadcast.v1.RoomLeaveEventH\x00\x12\x38\n\x06online\x18\x04 \x01(\x0b\x32&.bilibili.broadcast.v1.RoomOnlineEventH\x00\x12\x36\n\x03msg\x18\x05 \x01(\x0b\x32\'.bilibili.broadcast.v1.RoomMessageEventH\x00\x12\x34\n\x03\x65rr\x18\x06 \x01(\x0b\x32%.bilibili.broadcast.v1.RoomErrorEventH\x00\x42\x07\n\x05\x65vent2]\n\rBroadcastRoom\x12L\n\x05\x45nter\x12\x1e.bilibili.broadcast.v1.RoomReq\x1a\x1f.bilibili.broadcast.v1.RoomResp(\x01\x30\x01\x62\x06proto3')



_ROOMERROREVENT = DESCRIPTOR.message_types_by_name['RoomErrorEvent']
_ROOMJOINEVENT = DESCRIPTOR.message_types_by_name['RoomJoinEvent']
_ROOMLEAVEEVENT = DESCRIPTOR.message_types_by_name['RoomLeaveEvent']
_ROOMMESSAGEEVENT = DESCRIPTOR.message_types_by_name['RoomMessageEvent']
_ROOMONLINEEVENT = DESCRIPTOR.message_types_by_name['RoomOnlineEvent']
_ROOMREQ = DESCRIPTOR.message_types_by_name['RoomReq']
_ROOMRESP = DESCRIPTOR.message_types_by_name['RoomResp']
RoomErrorEvent = _reflection.GeneratedProtocolMessageType('RoomErrorEvent', (_message.Message,), {
  'DESCRIPTOR' : _ROOMERROREVENT,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomErrorEvent)
  })
_sym_db.RegisterMessage(RoomErrorEvent)

RoomJoinEvent = _reflection.GeneratedProtocolMessageType('RoomJoinEvent', (_message.Message,), {
  'DESCRIPTOR' : _ROOMJOINEVENT,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomJoinEvent)
  })
_sym_db.RegisterMessage(RoomJoinEvent)

RoomLeaveEvent = _reflection.GeneratedProtocolMessageType('RoomLeaveEvent', (_message.Message,), {
  'DESCRIPTOR' : _ROOMLEAVEEVENT,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomLeaveEvent)
  })
_sym_db.RegisterMessage(RoomLeaveEvent)

RoomMessageEvent = _reflection.GeneratedProtocolMessageType('RoomMessageEvent', (_message.Message,), {
  'DESCRIPTOR' : _ROOMMESSAGEEVENT,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomMessageEvent)
  })
_sym_db.RegisterMessage(RoomMessageEvent)

RoomOnlineEvent = _reflection.GeneratedProtocolMessageType('RoomOnlineEvent', (_message.Message,), {
  'DESCRIPTOR' : _ROOMONLINEEVENT,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomOnlineEvent)
  })
_sym_db.RegisterMessage(RoomOnlineEvent)

RoomReq = _reflection.GeneratedProtocolMessageType('RoomReq', (_message.Message,), {
  'DESCRIPTOR' : _ROOMREQ,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomReq)
  })
_sym_db.RegisterMessage(RoomReq)

RoomResp = _reflection.GeneratedProtocolMessageType('RoomResp', (_message.Message,), {
  'DESCRIPTOR' : _ROOMRESP,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomResp)
  })
_sym_db.RegisterMessage(RoomResp)

_BROADCASTROOM = DESCRIPTOR.services_by_name['BroadcastRoom']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROOMERROREVENT._serialized_start=113
  _ROOMERROREVENT._serialized_end=167
  _ROOMJOINEVENT._serialized_start=169
  _ROOMJOINEVENT._serialized_end=184
  _ROOMLEAVEEVENT._serialized_start=186
  _ROOMLEAVEEVENT._serialized_end=202
  _ROOMMESSAGEEVENT._serialized_start=204
  _ROOMMESSAGEEVENT._serialized_end=279
  _ROOMONLINEEVENT._serialized_start=281
  _ROOMONLINEEVENT._serialized_end=334
  _ROOMREQ._serialized_start=337
  _ROOMREQ._serialized_end=591
  _ROOMRESP._serialized_start=594
  _ROOMRESP._serialized_end=903
  _BROADCASTROOM._serialized_start=905
  _BROADCASTROOM._serialized_end=998
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/resource/privacy/v1/api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*bilibili/app/resource/privacy/v1/api.proto\x12 bilibili.app.resource.privacy.v1\"\x0e\n\x0cNoArgRequest\"\t\n\x07NoReply\"\xe3\x01\n\x11PrivacyConfigItem\x12P\n\x13privacy_config_type\x18\x01 \x01(\x0e\x32\x33.bilibili.app.resource.privacy.v1.PrivacyConfigType\x12\r\n\x05title\x18\x02 \x01(\t\x12\x43\n\x05state\x18\x03 \x01(\x0e\x32\x34.bilibili.app.resource.privacy.v1.PrivacyConfigState\x12\x11\n\tsub_title\x18\x04 \x01(\t\x12\x15\n\rsub_title_uri\x18\x05 \x01(\t\"f\n\x12PrivacyConfigReply\x12P\n\x13privacy_config_item\x18\x01 \x01(\x0b\x32\x33.bilibili.app.resource.privacy.v1.PrivacyConfigItem\"\xb0\x01\n\x17SetPrivacyConfigRequest\x12P\n\x13privacy_config_type\x18\x01 \x01(\x0e\x32\x33.bilibili.app.resource.privacy.v1.PrivacyConfigType\x12\x43\n\x05state\x18\x02 \x01(\x0e\x32\x34.bilibili.app.resource.privacy.v1.PrivacyConfigState*)\n\x12PrivacyConfigState\x12\t\n\x05\x63lose\x10\x00\x12\x08\n\x04open\x10\x01*/\n\x11PrivacyConfigType\x12\x08\n\x04none\x10\x00\x12\x10\n\x0c\x64ynamic_city\x10\x01\x32\xfa\x01\n\x07Privacy\x12u\n\rPrivacyConfig\x12..bilibili.app.resource.privacy.v1.NoArgRequest\x1a\x34.bilibili.app.resource.privacy.v1.PrivacyConfigReply\x12x\n\x10SetPrivacyConfig\x12\x39.bilibili.app.resource.privacy.v1.SetPrivacyConfigRequest\x1a).bilibili.app.resource.privacy.v1.NoReplyb\x06proto3')

_PRIVACYCONFIGSTATE = DESCRIPTOR.enum_types_by_name['PrivacyConfigState']
PrivacyConfigState = enum_type_wrapper.EnumTypeWrapper(_PRIVACYCONFIGSTATE)
_PRIVACYCONFIGTYPE = DESCRIPTOR.enum_types_by_name['PrivacyConfigType']
PrivacyConfigType = enum_type_wrapper.EnumTypeWrapper(_PRIVACYCONFIGTYPE)
close = 0
open = 1
none = 0
dynamic_city = 1


_NOARGREQUEST = DESCRIPTOR.message_types_by_name['NoArgRequest']
_NOREPLY = DESCRIPTOR.message_types_by_name['NoReply']
_PRIVACYCONFIGITEM = DESCRIPTOR.message_types_by_name['PrivacyConfigItem']
_PRIVACYCONFIGREPLY = DESCRIPTOR.message_types_by_name['PrivacyConfigReply']
_SETPRIVACYCONFIGREQUEST = DESCRIPTOR.message_types_by_name['SetPrivacyConfigRequest']
NoArgRequest = _reflection.GeneratedProtocolMessageType('NoArgRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOARGREQUEST,
  '__module__' : 'bilibili.app.resource.privacy.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.resource.privacy.v1.NoArgRequest)
  })
_sym_db.RegisterMessage(NoArgRequest)

NoReply = _reflection.GeneratedProtocolMessageType('NoReply', (_message.Message,), {
  'DESCRIPTOR' : _NOREPLY,
  '__module__' : 'bilibili.app.resource.privacy.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.resource.privacy.v1.NoReply)
  })
_sym_db.RegisterMessage(NoReply)

PrivacyConfigItem = _reflection.GeneratedProtocolMessageType('PrivacyConfigItem', (_message.Message,), {
  'DESCRIPTOR' : _PRIVACYCONFIGITEM,
  '__module__' : 'bilibili.app.resource.privacy.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.resource.privacy.v1.PrivacyConfigItem)
  })
_sym_db.RegisterMessage(PrivacyConfigItem)

PrivacyConfigReply = _reflection.GeneratedProtocolMessageType('PrivacyConfigReply', (_message.Message,), {
  'DESCRIPTOR' : _PRIVACYCONFIGREPLY,
  '__module__' : 'bilibili.app.resource.privacy.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.resource.privacy.v1.PrivacyConfigReply)
  })
_sym_db.RegisterMessage(PrivacyConfigReply)

SetPrivacyConfigRequest = _reflection.GeneratedProtocolMessageType('SetPrivacyConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPRIVACYCONFIGREQUEST,
  '__module__' : 'bilibili.app.resource.privacy.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.resource.privacy.v1.SetPrivacyConfigRequest)
  })
_sym_db.RegisterMessage(SetPrivacyConfigRequest)

_PRIVACY = DESCRIPTOR.services_by_name['Privacy']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PRIVACYCONFIGSTATE._serialized_start=620
  _PRIVACYCONFIGSTATE._serialized_end=661
  _PRIVACYCONFIGTYPE._serialized_start=663
  _PRIVACYCONFIGTYPE._serialized_end=710
  _NOARGREQUEST._serialized_start=80
  _NOARGREQUEST._serialized_end=94
  _NOREPLY._serialized_start=96
  _NOREPLY._serialized_end=105
  _PRIVACYCONFIGITEM._serialized_start=108
  _PRIVACYCONFIGITEM._serialized_end=335
  _PRIVACYCONFIGREPLY._serialized_start=337
  _PRIVACYCONFIGREPLY._serialized_end=439
  _SETPRIVACYCONFIGREQUEST._serialized_start=442
  _SETPRIVACYCONFIGREQUEST._serialized_end=618
  _PRIVACY._serialized_start=713
  _PRIVACY._serialized_end=963
# @@protoc_insertion_point(module_scope)



import os
import subprocess
from pathlib import Path


os.chdir(Path(__file__).parent.absolute() / "protos")


for file_path in Path(".").rglob("*.proto"):
    if file_path.is_file():
        subprocess.run(
            [
                "python",
                "-m",
                "grpc_tools.protoc",
                "-I=.",
                "--python_out=.",
                "--grpc_python_out=.",
                "--mypy_out=.",
                str(file_path),
            ],
            shell=True,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/pgc/gateway/player/v1/playurl.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilibili.app.playurl.v1 import playurl_pb2 as bilibili_dot_app_dot_playurl_dot_v1_dot_playurl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/pgc/gateway/player/v1/playurl.proto\x12\x1e\x62ilibili.pgc.gateway.player.v1\x1a%bilibili/app/playurl/v1/playurl.proto\"D\n\x0c\x42usinessInfo\x12\x12\n\nis_preview\x18\x01 \x01(\x08\x12\n\n\x02\x62p\x18\x02 \x01(\x08\x12\x14\n\x0cmarlin_token\x18\x03 \x01(\t\"=\n\x05\x45vent\x12\x34\n\x05shake\x18\x01 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v1.Shake\"\xb2\x01\n\x0cLivePlayInfo\x12\x12\n\ncurrent_qn\x18\x01 \x01(\x05\x12O\n\x13quality_description\x18\x02 \x03(\x0b\x32\x32.bilibili.pgc.gateway.player.v1.QualityDescription\x12=\n\x04\x64url\x18\x03 \x03(\x0b\x32/.bilibili.pgc.gateway.player.v1.ResponseDataUrl\"\x91\x01\n\x11LivePlayViewReply\x12;\n\troom_info\x18\x01 \x01(\x0b\x32(.bilibili.pgc.gateway.player.v1.RoomInfo\x12?\n\tplay_info\x18\x02 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v1.LivePlayInfo\"w\n\x0fLivePlayViewReq\x12\r\n\x05\x65p_id\x18\x01 \x01(\x03\x12\x0f\n\x07quality\x18\x02 \x01(\r\x12\r\n\x05ptype\x18\x03 \x01(\r\x12\r\n\x05https\x18\x04 \x01(\x08\x12\x11\n\tplay_type\x18\x05 \x01(\r\x12\x13\n\x0b\x64\x65vice_type\x18\x06 \x01(\x05\"\xae\x06\n\x0fPlayAbilityConf\x12\x1f\n\x17\x62\x61\x63kground_play_disable\x18\x01 \x01(\x08\x12\x14\n\x0c\x66lip_disable\x18\x02 \x01(\x08\x12\x14\n\x0c\x63\x61st_disable\x18\x03 \x01(\x08\x12\x18\n\x10\x66\x65\x65\x64\x62\x61\x63k_disable\x18\x04 \x01(\x08\x12\x18\n\x10subtitle_disable\x18\x05 \x01(\x08\x12\x1d\n\x15playback_rate_disable\x18\x06 \x01(\x08\x12\x17\n\x0ftime_up_disable\x18\x07 \x01(\x08\x12\x1d\n\x15playback_mode_disable\x18\x08 \x01(\x08\x12\x1a\n\x12scale_mode_disable\x18\t \x01(\x08\x12\x14\n\x0clike_disable\x18\n \x01(\x08\x12\x17\n\x0f\x64islike_disable\x18\x0b \x01(\x08\x12\x14\n\x0c\x63oin_disable\x18\x0c \x01(\x08\x12\x14\n\x0c\x65lec_disable\x18\r \x01(\x08\x12\x15\n\rshare_disable\x18\x0e \x01(\x08\x12\x1b\n\x13screen_shot_disable\x18\x0f \x01(\x08\x12\x1b\n\x13lock_screen_disable\x18\x10 \x01(\x08\x12\x19\n\x11recommend_disable\x18\x11 \x01(\x08\x12\x1e\n\x16playback_speed_disable\x18\x12 \x01(\x08\x12\x1a\n\x12\x64\x65\x66inition_disable\x18\x13 \x01(\x08\x12\x1a\n\x12selections_disable\x18\x14 \x01(\x08\x12\x14\n\x0cnext_disable\x18\x15 \x01(\x08\x12\x17\n\x0f\x65\x64it_dm_disable\x18\x16 \x01(\x08\x12\x1c\n\x14small_window_disable\x18\x17 \x01(\x08\x12\x15\n\rshake_disable\x18\x18 \x01(\x08\x12\x18\n\x10outer_dm_disable\x18\x19 \x01(\x08\x12\x18\n\x10inner_dm_disable\x18\x1a \x01(\x08\x12\x1b\n\x13\x66reya_enter_disable\x18\x1b \x01(\x08\x12\x15\n\rdolby_disable\x18\x1c \x01(\x08\x12\x1a\n\x12\x66reya_full_disable\x18\x1d \x01(\x08\x12 \n\x18skip_oped_switch_disable\x18\x1e \x01(\x08\"\x81\x02\n\rPlayViewReply\x12\x36\n\nvideo_info\x18\x01 \x01(\x0b\x32\".bilibili.app.playurl.v1.VideoInfo\x12\x42\n\tplay_conf\x18\x02 \x01(\x0b\x32/.bilibili.pgc.gateway.player.v1.PlayAbilityConf\x12>\n\x08\x62usiness\x18\x03 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v1.BusinessInfo\x12\x34\n\x05\x65vent\x18\x04 \x01(\x0b\x32%.bilibili.pgc.gateway.player.v1.Event\"\xa5\x02\n\x0bPlayViewReq\x12\x0c\n\x04\x65pid\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x12\n\nforce_host\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x12\n\nfrom_spmid\x18\n \x01(\t\x12\x16\n\x0eteenagers_mode\x18\x0b \x01(\x05\x12<\n\x11prefer_codec_type\x18\x0c \x01(\x0e\x32!.bilibili.app.playurl.v1.CodeType\x12\x12\n\nis_preview\x18\r \x01(\x08\x12\x0f\n\x07room_id\x18\x0e \x01(\x03\"F\n\x0cProjectReply\x12\x36\n\x07project\x18\x01 \x01(\x0b\x32%.bilibili.app.playurl.v1.PlayURLReply\"\xed\x01\n\nProjectReq\x12\r\n\x05\x65p_id\x18\x01 \x01(\x03\x12\x0b\n\x03\x63id\x18\x02 \x01(\x03\x12\n\n\x02qn\x18\x03 \x01(\x03\x12\r\n\x05\x66nver\x18\x04 \x01(\x05\x12\r\n\x05\x66nval\x18\x05 \x01(\x05\x12\x10\n\x08\x64ownload\x18\x06 \x01(\r\x12\x11\n\tforceHost\x18\x07 \x01(\x05\x12\r\n\x05\x66ourk\x18\x08 \x01(\x08\x12\r\n\x05spmid\x18\t \x01(\t\x12\x11\n\tfromSpmid\x18\n \x01(\t\x12\x10\n\x08protocol\x18\x0b \x01(\x05\x12\x13\n\x0b\x64\x65vice_type\x18\x0c \x01(\x05\x12\x1c\n\x14use_new_project_code\x18\r \x01(\x08\".\n\x12QualityDescription\x12\n\n\x02qn\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"A\n\x0fResponseDataUrl\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0bstream_type\x18\x02 \x01(\r\x12\x0c\n\x04ptag\x18\x03 \x01(\r\"\xa4\x01\n\x08RoomInfo\x12\x0f\n\x07room_id\x18\x01 \x01(\x03\x12\x0b\n\x03uid\x18\x02 \x01(\x03\x12>\n\x06status\x18\x03 \x01(\x0b\x32..bilibili.pgc.gateway.player.v1.RoomStatusInfo\x12:\n\x04show\x18\x04 \x01(\x0b\x32,.bilibili.pgc.gateway.player.v1.RoomShowInfo\"S\n\x0cRoomShowInfo\x12\x10\n\x08short_id\x18\x01 \x01(\x03\x12\x18\n\x10popularity_count\x18\x08 \x01(\x03\x12\x17\n\x0flive_start_time\x18\n \x01(\x03\"\xce\x01\n\x0eRoomStatusInfo\x12\x13\n\x0blive_status\x18\x01 \x01(\x03\x12\x18\n\x10live_screen_type\x18\x02 \x01(\x03\x12\x11\n\tlive_mark\x18\x03 \x01(\x03\x12\x13\n\x0block_status\x18\x04 \x01(\x03\x12\x11\n\tlock_time\x18\x05 \x01(\x03\x12\x15\n\rhidden_status\x18\x06 \x01(\x03\x12\x13\n\x0bhidden_time\x18\x07 \x01(\x03\x12\x11\n\tlive_type\x18\x08 \x01(\x03\x12\x13\n\x0broom_shield\x18\t \x01(\x03\"\x15\n\x05Shake\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t2\xca\x02\n\x07PlayURL\x12\x66\n\x08PlayView\x12+.bilibili.pgc.gateway.player.v1.PlayViewReq\x1a-.bilibili.pgc.gateway.player.v1.PlayViewReply\x12\x63\n\x07Project\x12*.bilibili.pgc.gateway.player.v1.ProjectReq\x1a,.bilibili.pgc.gateway.player.v1.ProjectReply\x12r\n\x0cLivePlayView\x12/.bilibili.pgc.gateway.player.v1.LivePlayViewReq\x1a\x31.bilibili.pgc.gateway.player.v1.LivePlayViewReplyb\x06proto3')



_BUSINESSINFO = DESCRIPTOR.message_types_by_name['BusinessInfo']
_EVENT = DESCRIPTOR.message_types_by_name['Event']
_LIVEPLAYINFO = DESCRIPTOR.message_types_by_name['LivePlayInfo']
_LIVEPLAYVIEWREPLY = DESCRIPTOR.message_types_by_name['LivePlayViewReply']
_LIVEPLAYVIEWREQ = DESCRIPTOR.message_types_by_name['LivePlayViewReq']
_PLAYABILITYCONF = DESCRIPTOR.message_types_by_name['PlayAbilityConf']
_PLAYVIEWREPLY = DESCRIPTOR.message_types_by_name['PlayViewReply']
_PLAYVIEWREQ = DESCRIPTOR.message_types_by_name['PlayViewReq']
_PROJECTREPLY = DESCRIPTOR.message_types_by_name['ProjectReply']
_PROJECTREQ = DESCRIPTOR.message_types_by_name['ProjectReq']
_QUALITYDESCRIPTION = DESCRIPTOR.message_types_by_name['QualityDescription']
_RESPONSEDATAURL = DESCRIPTOR.message_types_by_name['ResponseDataUrl']
_ROOMINFO = DESCRIPTOR.message_types_by_name['RoomInfo']
_ROOMSHOWINFO = DESCRIPTOR.message_types_by_name['RoomShowInfo']
_ROOMSTATUSINFO = DESCRIPTOR.message_types_by_name['RoomStatusInfo']
_SHAKE = DESCRIPTOR.message_types_by_name['Shake']
BusinessInfo = _reflection.GeneratedProtocolMessageType('BusinessInfo', (_message.Message,), {
  'DESCRIPTOR' : _BUSINESSINFO,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.BusinessInfo)
  })
_sym_db.RegisterMessage(BusinessInfo)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.Event)
  })
_sym_db.RegisterMessage(Event)

LivePlayInfo = _reflection.GeneratedProtocolMessageType('LivePlayInfo', (_message.Message,), {
  'DESCRIPTOR' : _LIVEPLAYINFO,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.LivePlayInfo)
  })
_sym_db.RegisterMessage(LivePlayInfo)

LivePlayViewReply = _reflection.GeneratedProtocolMessageType('LivePlayViewReply', (_message.Message,), {
  'DESCRIPTOR' : _LIVEPLAYVIEWREPLY,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.LivePlayViewReply)
  })
_sym_db.RegisterMessage(LivePlayViewReply)

LivePlayViewReq = _reflection.GeneratedProtocolMessageType('LivePlayViewReq', (_message.Message,), {
  'DESCRIPTOR' : _LIVEPLAYVIEWREQ,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.LivePlayViewReq)
  })
_sym_db.RegisterMessage(LivePlayViewReq)

PlayAbilityConf = _reflection.GeneratedProtocolMessageType('PlayAbilityConf', (_message.Message,), {
  'DESCRIPTOR' : _PLAYABILITYCONF,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.PlayAbilityConf)
  })
_sym_db.RegisterMessage(PlayAbilityConf)

PlayViewReply = _reflection.GeneratedProtocolMessageType('PlayViewReply', (_message.Message,), {
  'DESCRIPTOR' : _PLAYVIEWREPLY,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.PlayViewReply)
  })
_sym_db.RegisterMessage(PlayViewReply)

PlayViewReq = _reflection.GeneratedProtocolMessageType('PlayViewReq', (_message.Message,), {
  'DESCRIPTOR' : _PLAYVIEWREQ,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.PlayViewReq)
  })
_sym_db.RegisterMessage(PlayViewReq)

ProjectReply = _reflection.GeneratedProtocolMessageType('ProjectReply', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTREPLY,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.ProjectReply)
  })
_sym_db.RegisterMessage(ProjectReply)

ProjectReq = _reflection.GeneratedProtocolMessageType('ProjectReq', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTREQ,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.ProjectReq)
  })
_sym_db.RegisterMessage(ProjectReq)

QualityDescription = _reflection.GeneratedProtocolMessageType('QualityDescription', (_message.Message,), {
  'DESCRIPTOR' : _QUALITYDESCRIPTION,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.QualityDescription)
  })
_sym_db.RegisterMessage(QualityDescription)

ResponseDataUrl = _reflection.GeneratedProtocolMessageType('ResponseDataUrl', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEDATAURL,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.ResponseDataUrl)
  })
_sym_db.RegisterMessage(ResponseDataUrl)

RoomInfo = _reflection.GeneratedProtocolMessageType('RoomInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROOMINFO,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.RoomInfo)
  })
_sym_db.RegisterMessage(RoomInfo)

RoomShowInfo = _reflection.GeneratedProtocolMessageType('RoomShowInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROOMSHOWINFO,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.RoomShowInfo)
  })
_sym_db.RegisterMessage(RoomShowInfo)

RoomStatusInfo = _reflection.GeneratedProtocolMessageType('RoomStatusInfo', (_message.Message,), {
  'DESCRIPTOR' : _ROOMSTATUSINFO,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.RoomStatusInfo)
  })
_sym_db.RegisterMessage(RoomStatusInfo)

Shake = _reflection.GeneratedProtocolMessageType('Shake', (_message.Message,), {
  'DESCRIPTOR' : _SHAKE,
  '__module__' : 'bilibili.pgc.gateway.player.v1.playurl_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.pgc.gateway.player.v1.Shake)
  })
_sym_db.RegisterMessage(Shake)

_PLAYURL = DESCRIPTOR.services_by_name['PlayURL']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BUSINESSINFO._serialized_start=119
  _BUSINESSINFO._serialized_end=187
  _EVENT._serialized_start=189
  _EVENT._serialized_end=250
  _LIVEPLAYINFO._serialized_start=253
  _LIVEPLAYINFO._serialized_end=431
  _LIVEPLAYVIEWREPLY._serialized_start=434
  _LIVEPLAYVIEWREPLY._serialized_end=579
  _LIVEPLAYVIEWREQ._serialized_start=581
  _LIVEPLAYVIEWREQ._serialized_end=700
  _PLAYABILITYCONF._serialized_start=703
  _PLAYABILITYCONF._serialized_end=1517
  _PLAYVIEWREPLY._serialized_start=1520
  _PLAYVIEWREPLY._serialized_end=1777
  _PLAYVIEWREQ._serialized_start=1780
  _PLAYVIEWREQ._serialized_end=2073
  _PROJECTREPLY._serialized_start=2075
  _PROJECTREPLY._serialized_end=2145
  _PROJECTREQ._serialized_start=2148
  _PROJECTREQ._serialized_end=2385
  _QUALITYDESCRIPTION._serialized_start=2387
  _QUALITYDESCRIPTION._serialized_end=2433
  _RESPONSEDATAURL._serialized_start=2435
  _RESPONSEDATAURL._serialized_end=2500
  _ROOMINFO._serialized_start=2503
  _ROOMINFO._serialized_end=2667
  _ROOMSHOWINFO._serialized_start=2669
  _ROOMSHOWINFO._serialized_end=2752
  _ROOMSTATUSINFO._serialized_start=2755
  _ROOMSTATUSINFO._serialized_end=2961
  _SHAKE._serialized_start=2963
  _SHAKE._serialized_end=2984
  _PLAYURL._serialized_start=2987
  _PLAYURL._serialized_end=3317
# @@protoc_insertion_point(module_scope)



from ..protos.bilibili.app.dynamic.v2.dynamic_pb2 import (
    DynAllReq,
    DynMixUpListViewMoreReq,
    DynSpaceReq,
    DynSpaceRsp,
)
from ..protos.bilibili.app.dynamic.v2.dynamic_pb2_grpc import DynamicStub
from ..utils import grpc_request


@grpc_request
async def grpc_get_user_dynamics(
    uid: int, offset: str = "", page: int = 1, **kwargs
) -> DynSpaceRsp:
    stub = DynamicStub(kwargs.pop("_channel"))
    req = DynSpaceReq(host_uid=uid, history_offset=offset, page=page)
    return await stub.DynSpace(req, **kwargs)


@grpc_request
async def grpc_get_followed_dynamics(**kwargs):
    stub = DynamicStub(kwargs.pop("_channel"))
    req = DynAllReq()
    return await stub.DynAll(req, **kwargs)

    # exclude_list = [DynamicType.ad, DynamicType.live, DynamicType.live_rcmd]
    # dynlist = filter(
    #     lambda x: x.card_type not in exclude_list,
    #     resp.dynamic_list.list,
    # )
    # return list(dynlist)


@grpc_request
async def grpc_get_followed_dynamic_users(**kwargs):
    stub = DynamicStub(kwargs.pop("_channel"))
    req = DynMixUpListViewMoreReq(sort_type=1)
    return await stub.DynMixUpListViewMore(req, **kwargs)



import sys
from pathlib import Path

# from .login import Login
from .utils import get, post  # noqa

sys.path.append(str(Path(__file__).absolute().parent / "grpc" / "protos"))

# class BaseAPI:
#     def __init__(
#         self,
#         access_token=None,
#         refresh_token=None,
#         sessdata=None,
#         bili_jct=None,
#         token=None,
#     ):
#         pass


# class Self:
#     def __init__(self, access_token, refresh_token, sessdata, bili_jct):
#         self.access_token = access_token
#         self.refresh_token = refresh_token
#         self.bilisessdata = sessdata
#         self.bilijct = bili_jct
#         self.login = Login()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/im/type/im.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x62ilibili/im/type/im.proto\x12\x10\x62ilibili.im.type\",\n\x0b\x41\x63\x63ountInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07pic_url\x18\x02 \x01(\t\"Q\n\x0e\x46riendRelation\x12\x0b\n\x03uid\x18\x01 \x01(\x04\x12\x11\n\tuser_name\x18\x02 \x01(\t\x12\x0c\n\x04\x66\x61\x63\x65\x18\x03 \x01(\t\x12\x11\n\tvip_level\x18\x04 \x01(\r\"\xeb\x01\n\rGroupRelation\x12\x10\n\x08group_id\x18\x01 \x01(\x04\x12\x11\n\towner_uid\x18\x02 \x01(\x04\x12\x12\n\ngroup_type\x18\x03 \x01(\r\x12\x13\n\x0bgroup_level\x18\x04 \x01(\r\x12\x13\n\x0bgroup_cover\x18\x05 \x01(\t\x12\x12\n\ngroup_name\x18\x06 \x01(\t\x12\x14\n\x0cgroup_notice\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\x05\x12\x13\n\x0bmember_role\x18\t \x01(\x05\x12\x17\n\x0f\x66\x61ns_medal_name\x18\n \x01(\t\x12\x0f\n\x07room_id\x18\x0b \x01(\x04\"5\n\x08HighText\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\r\"H\n\x07ImgInfo\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\x11\n\timageType\x18\x04 \x01(\t\"\\\n\x0bKeyHitInfos\x12\r\n\x05toast\x18\x01 \x01(\t\x12\x0f\n\x07rule_id\x18\x02 \x01(\r\x12-\n\thigh_text\x18\x03 \x03(\x0b\x32\x1a.bilibili.im.type.HighText\"\xcf\x03\n\x03Msg\x12\x12\n\nsender_uid\x18\x01 \x01(\x04\x12\x33\n\rreceiver_type\x18\x02 \x01(\x0e\x32\x1c.bilibili.im.type.RecverType\x12\x13\n\x0breceiver_id\x18\x03 \x01(\x04\x12\x12\n\ncli_msg_id\x18\x04 \x01(\x04\x12+\n\x08msg_type\x18\x05 \x01(\x0e\x32\x19.bilibili.im.type.MsgType\x12\x0f\n\x07\x63ontent\x18\x06 \x01(\t\x12\x11\n\tmsg_seqno\x18\x07 \x01(\x04\x12\x11\n\ttimestamp\x18\x08 \x01(\x04\x12\x0f\n\x07\x61t_uids\x18\t \x03(\x04\x12\x12\n\nrecver_ids\x18\n \x03(\x04\x12\x0f\n\x07msg_key\x18\x0b \x01(\x04\x12\x12\n\nmsg_status\x18\x0c \x01(\r\x12\x12\n\nsys_cancel\x18\r \x01(\x08\x12\x13\n\x0bnotify_code\x18\x0e \x01(\t\x12/\n\nmsg_source\x18\x0f \x01(\x0e\x32\x1b.bilibili.im.type.MsgSource\x12\x18\n\x10new_face_version\x18\x10 \x01(\x05\x12\x34\n\rkey_hit_infos\x18\x11 \x01(\x0b\x32\x1d.bilibili.im.type.KeyHitInfos\"\xcb\x01\n\x0bRelationLog\x12\x33\n\x08log_type\x18\x01 \x01(\x0e\x32!.bilibili.im.type.RelationLogType\x12\x13\n\x0boplog_seqno\x18\x02 \x01(\x04\x12\x39\n\x0f\x66riend_relation\x18\x03 \x01(\x0b\x32 .bilibili.im.type.FriendRelation\x12\x37\n\x0egroup_relation\x18\x04 \x01(\x0b\x32\x1f.bilibili.im.type.GroupRelation\"\xaa\x04\n\x0bSessionInfo\x12\x11\n\ttalker_id\x18\x01 \x01(\x04\x12\x14\n\x0csession_type\x18\x02 \x01(\r\x12\x10\n\x08\x61t_seqno\x18\x03 \x01(\x04\x12\x0e\n\x06top_ts\x18\x04 \x01(\x04\x12\x12\n\ngroup_name\x18\x05 \x01(\t\x12\x13\n\x0bgroup_cover\x18\x06 \x01(\t\x12\x11\n\tis_follow\x18\x07 \x01(\r\x12\x0e\n\x06is_dnd\x18\x08 \x01(\r\x12\x11\n\tack_seqno\x18\t \x01(\x04\x12\x0e\n\x06\x61\x63k_ts\x18\n \x01(\x04\x12\x12\n\nsession_ts\x18\x0b \x01(\x04\x12\x14\n\x0cunread_count\x18\x0c \x01(\r\x12\'\n\x08last_msg\x18\r \x01(\x0b\x32\x15.bilibili.im.type.Msg\x12\x12\n\ngroup_type\x18\x0e \x01(\r\x12\x10\n\x08\x63\x61n_fold\x18\x0f \x01(\r\x12\x0e\n\x06status\x18\x10 \x01(\r\x12\x11\n\tmax_seqno\x18\x11 \x01(\x04\x12\x14\n\x0cnew_push_msg\x18\x12 \x01(\r\x12\x0f\n\x07setting\x18\x13 \x01(\r\x12\x13\n\x0bis_guardian\x18\x14 \x01(\r\x12\x14\n\x0cis_intercept\x18\x15 \x01(\x05\x12\x10\n\x08is_trust\x18\x16 \x01(\x05\x12\x17\n\x0fsystem_msg_type\x18\x17 \x01(\x05\x12\x33\n\x0c\x61\x63\x63ount_info\x18\x18 \x01(\x0b\x32\x1d.bilibili.im.type.AccountInfo\x12\x13\n\x0blive_status\x18\x19 \x01(\x05*\x94\x06\n\x05\x43mdId\x12\x15\n\x11\x45N_CMD_ID_INVALID\x10\x00\x12\x18\n\x12\x45N_CMD_ID_SEND_MSG\x10\xc1\x9a\x0c\x12\x18\n\x12\x45N_CMD_ID_SYNC_MSG\x10\xa1\xc2\x1e\x12\x1d\n\x17\x45N_CMD_ID_SYNC_RELATION\x10\xa2\xc2\x1e\x12\x18\n\x12\x45N_CMD_ID_SYNC_ACK\x10\xa3\xc2\x1e\x12\'\n!EN_CMD_ID_SYNC_FETCH_SESSION_MSGS\x10\xa6\xc2\x1e\x12(\n\"EN_CMD_ID_SESSION_SVR_GET_SESSIONS\x10\xc1\x84=\x12(\n\"EN_CMD_ID_SESSION_SVR_NEW_SESSIONS\x10\xc2\x84=\x12(\n\"EN_CMD_ID_SESSION_SVR_ACK_SESSIONS\x10\xc3\x84=\x12&\n EN_CMD_ID_SESSION_SVR_UPDATE_ACK\x10\xc4\x84=\x12#\n\x1d\x45N_CMD_ID_SESSION_SVR_SET_TOP\x10\xc5\x84=\x12*\n$EN_CMD_ID_SESSION_SVR_REMOVE_SESSION\x10\xc7\x84=\x12)\n#EN_CMD_ID_SESSION_SVR_SINGLE_UNREAD\x10\xc8\x84=\x12+\n%EN_CMD_ID_SESSION_SVR_MY_GROUP_UNREAD\x10\xc9\x84=\x12-\n\'EN_CMD_ID_SESSION_SVR_UPDATE_UNFLW_READ\x10\xca\x84=\x12+\n%EN_CMD_ID_SESSION_SVR_GROUP_ASSIS_MSG\x10\xcb\x84=\x12)\n#EN_CMD_ID_SESSION_SVR_ACK_ASSIS_MSG\x10\xcc\x84=\x12*\n$EN_CMD_ID_SESSION_SVR_SESSION_DETAIL\x10\xcf\x84=\x12-\n\'EN_CMD_ID_SESSION_SVR_BATCH_SESS_DETAIL\x10\xd0\x84=\x12-\n\'EN_CMD_ID_SESSION_SVR_BATCH_RM_SESSIONS\x10\xd1\x84=*I\n\x11\x45NUM_BIZ_MSG_TYPE\x12\x17\n\x13\x42IZ_MSG_TYPE_NORMAL\x10\x00\x12\x1b\n\x17\x42IZ_MSG_TYPE_CARD_VIDEO\x10\x01*\x94\x03\n\tMsgSource\x12\x18\n\x14\x45N_MSG_SOURCE_UNKONW\x10\x00\x12\x15\n\x11\x45N_MSG_SOURCE_IOS\x10\x01\x12\x19\n\x15\x45N_MSG_SOURCE_ANDRIOD\x10\x02\x12\x14\n\x10\x45N_MSG_SOURCE_H5\x10\x03\x12\x14\n\x10\x45N_MSG_SOURCE_PC\x10\x04\x12\x1b\n\x17\x45N_MSG_SOURCE_BACKSTAGE\x10\x05\x12\x15\n\x11\x45N_MSG_SOURCE_BIZ\x10\x06\x12\x15\n\x11\x45N_MSG_SOURCE_WEB\x10\x07\x12\'\n#EN_MSG_SOURCE_AUTOREPLY_BY_FOLLOWED\x10\x08\x12*\n&EN_MSG_SOURCE_AUTOREPLY_BY_RECEIVE_MSG\x10\t\x12\'\n#EN_MSG_SOURCE_AUTOREPLY_BY_KEYWORDS\x10\n\x12%\n!EN_MSG_SOURCE_AUTOREPLY_BY_VOYAGE\x10\x0b\x12\x1f\n\x1b\x45N_MSG_SOURCE_VC_ATTACH_MSG\x10\x0c*\xeb\x0e\n\x07MsgType\x12\x17\n\x13\x45N_INVALID_MSG_TYPE\x10\x00\x12\x14\n\x10\x45N_MSG_TYPE_TEXT\x10\x01\x12\x13\n\x0f\x45N_MSG_TYPE_PIC\x10\x02\x12\x15\n\x11\x45N_MSG_TYPE_AUDIO\x10\x03\x12\x15\n\x11\x45N_MSG_TYPE_SHARE\x10\x04\x12\x19\n\x15\x45N_MSG_TYPE_DRAW_BACK\x10\x05\x12\x1b\n\x17\x45N_MSG_TYPE_CUSTOM_FACE\x10\x06\x12\x18\n\x14\x45N_MSG_TYPE_SHARE_V2\x10\x07\x12\x1a\n\x16\x45N_MSG_TYPE_SYS_CANCEL\x10\x08\x12\x1c\n\x18\x45N_MSG_TYPE_MINI_PROGRAM\x10\t\x12\x1a\n\x16\x45N_MSG_TYPE_NOTIFY_MSG\x10\n\x12\x1a\n\x16\x45N_MSG_TYPE_VIDEO_CARD\x10\x0b\x12\x1c\n\x18\x45N_MSG_TYPE_ARTICLE_CARD\x10\x0c\x12\x1c\n\x18\x45N_MSG_TYPE_PICTURE_CARD\x10\r\x12!\n\x1d\x45N_MSG_TYPE_COMMON_SHARE_CARD\x10\x0e\x12\x1c\n\x18\x45N_MSG_TYPE_BIZ_MSG_TYPE\x10\x32\x12$\n EN_MSG_TYPE_GROUP_MEMBER_CHANGED\x10\x65\x12$\n EN_MSG_TYPE_GROUP_STATUS_CHANGED\x10\x66\x12%\n!EN_MSG_TYPE_GROUP_DYNAMIC_CHANGED\x10g\x12\"\n\x1e\x45N_MSG_TYPE_GROUP_LIST_CHANGED\x10h\x12#\n\x1f\x45M_MSG_TYPE_FRIEND_LIST_CHANGED\x10i\x12$\n EN_MSG_TYPE_GROUP_DETAIL_CHANGED\x10j\x12)\n%EN_MSG_TYPE_GROUP_MEMBER_ROLE_CHANGED\x10k\x12!\n\x1d\x45N_MSG_TYPE_NOTICE_WATCH_LIST\x10l\x12)\n%EN_MSG_TYPE_NOTIFY_NEW_REPLY_RECIEVED\x10m\x12&\n\"EN_MSG_TYPE_NOTIFY_NEW_AT_RECIEVED\x10n\x12*\n&EN_MSG_TYPE_NOTIFY_NEW_PRAISE_RECIEVED\x10o\x12&\n\"EN_MSG_TYPE_NOTIFY_NEW_UP_RECIEVED\x10p\x12,\n(EN_MSG_TYPE_NOTIFY_NEW_REPLY_RECIEVED_V2\x10q\x12)\n%EN_MSG_TYPE_NOTIFY_NEW_AT_RECIEVED_V2\x10r\x12-\n)EN_MSG_TYPE_NOTIFY_NEW_PRAISE_RECIEVED_V2\x10s\x12*\n&EN_MSG_TYPE_GROUP_DETAIL_CHANGED_MULTI\x10t\x12/\n+EN_MSG_TYPE_GROUP_MEMBER_ROLE_CHANGED_MULTI\x10u\x12#\n\x1f\x45N_MSG_TYPE_NOTIFY_ANTI_DISTURB\x10v\x12$\n\x1f\x45N_MSG_TYPE_SYS_GROUP_DISSOLVED\x10\xc9\x01\x12!\n\x1c\x45N_MSG_TYPE_SYS_GROUP_JOINED\x10\xca\x01\x12(\n#EN_MSG_TYPE_SYS_GROUP_MEMBER_EXITED\x10\xcb\x01\x12&\n!EN_MSG_TYPE_SYS_GROUP_ADMIN_FIRED\x10\xcc\x01\x12(\n#EN_MSG_TYPE_SYS_GROUP_MEMBER_KICKED\x10\xcd\x01\x12)\n$EN_MSG_TYPE_SYS_GROUP_ADMIN_KICK_OFF\x10\xce\x01\x12%\n EN_MSG_TYPE_SYS_GROUP_ADMIN_DUTY\x10\xcf\x01\x12\'\n\"EN_MSG_TYPE_SYS_GROUP_AUTO_CREATED\x10\xd0\x01\x12!\n\x1c\x45N_MSG_TYPE_SYS_FRIEND_APPLY\x10\xd2\x01\x12%\n EN_MSG_TYPE_SYS_FRIEND_APPLY_ACK\x10\xd3\x01\x12,\n\'EN_MSG_TYPE_SYS_GROUP_APPLY_FOR_JOINING\x10\xd4\x01\x12\x34\n/EN_MSG_TYPE_SYS_GROUP_ADMIN_ACCEPTED_USER_APPLY\x10\xd5\x01\x12#\n\x1e\x45N_MSG_TYPE_CHAT_MEMBER_JOINED\x10\xad\x02\x12#\n\x1e\x45N_MSG_TYPE_CHAT_MEMBER_EXITED\x10\xae\x02\x12#\n\x1e\x45N_MSG_TYPE_CHAT_GROUP_FREEZED\x10\xaf\x02\x12%\n EN_MSG_TYPE_CHAT_GROUP_DISSOLVED\x10\xb0\x02\x12#\n\x1e\x45N_MSG_TYPE_CHAT_GROUP_CREATED\x10\xb1\x02\x12#\n\x1e\x45N_MSG_TYPE_CHAT_POPUP_SESSION\x10\xb2\x02*l\n\nRecverType\x12\x11\n\rEN_NO_MEANING\x10\x00\x12\x17\n\x13\x45N_RECVER_TYPE_PEER\x10\x01\x12\x18\n\x14\x45N_RECVER_TYPE_GROUP\x10\x02\x12\x18\n\x14\x45N_RECVER_TYPE_PEERS\x10\x03*y\n\x0fRelationLogType\x12\x17\n\x13\x45N_INVALID_LOG_TYPE\x10\x00\x12\x11\n\rEN_ADD_FRIEND\x10\x01\x12\x14\n\x10\x45N_REMOVE_FRIEND\x10\x02\x12\x11\n\rEN_JOIN_GROUP\x10\x03\x12\x11\n\rEN_EXIT_GROUP\x10\x04*\x82\x01\n\x0cSESSION_TYPE\x12\x18\n\x14INVALID_SESSION_TYPE\x10\x00\x12\x13\n\x0fUN_FOLD_SESSION\x10\x01\x12\x1c\n\x18UN_FOLLOW_SINGLE_SESSION\x10\x02\x12\x14\n\x10MY_GROUP_SESSION\x10\x03\x12\x0f\n\x0b\x41LL_SESSION\x10\x04\x62\x06proto3')

_CMDID = DESCRIPTOR.enum_types_by_name['CmdId']
CmdId = enum_type_wrapper.EnumTypeWrapper(_CMDID)
_ENUM_BIZ_MSG_TYPE = DESCRIPTOR.enum_types_by_name['ENUM_BIZ_MSG_TYPE']
ENUM_BIZ_MSG_TYPE = enum_type_wrapper.EnumTypeWrapper(_ENUM_BIZ_MSG_TYPE)
_MSGSOURCE = DESCRIPTOR.enum_types_by_name['MsgSource']
MsgSource = enum_type_wrapper.EnumTypeWrapper(_MSGSOURCE)
_MSGTYPE = DESCRIPTOR.enum_types_by_name['MsgType']
MsgType = enum_type_wrapper.EnumTypeWrapper(_MSGTYPE)
_RECVERTYPE = DESCRIPTOR.enum_types_by_name['RecverType']
RecverType = enum_type_wrapper.EnumTypeWrapper(_RECVERTYPE)
_RELATIONLOGTYPE = DESCRIPTOR.enum_types_by_name['RelationLogType']
RelationLogType = enum_type_wrapper.EnumTypeWrapper(_RELATIONLOGTYPE)
_SESSION_TYPE = DESCRIPTOR.enum_types_by_name['SESSION_TYPE']
SESSION_TYPE = enum_type_wrapper.EnumTypeWrapper(_SESSION_TYPE)
EN_CMD_ID_INVALID = 0
EN_CMD_ID_SEND_MSG = 200001
EN_CMD_ID_SYNC_MSG = 500001
EN_CMD_ID_SYNC_RELATION = 500002
EN_CMD_ID_SYNC_ACK = 500003
EN_CMD_ID_SYNC_FETCH_SESSION_MSGS = 500006
EN_CMD_ID_SESSION_SVR_GET_SESSIONS = 1000001
EN_CMD_ID_SESSION_SVR_NEW_SESSIONS = 1000002
EN_CMD_ID_SESSION_SVR_ACK_SESSIONS = 1000003
EN_CMD_ID_SESSION_SVR_UPDATE_ACK = 1000004
EN_CMD_ID_SESSION_SVR_SET_TOP = 1000005
EN_CMD_ID_SESSION_SVR_REMOVE_SESSION = 1000007
EN_CMD_ID_SESSION_SVR_SINGLE_UNREAD = 1000008
EN_CMD_ID_SESSION_SVR_MY_GROUP_UNREAD = 1000009
EN_CMD_ID_SESSION_SVR_UPDATE_UNFLW_READ = 1000010
EN_CMD_ID_SESSION_SVR_GROUP_ASSIS_MSG = 1000011
EN_CMD_ID_SESSION_SVR_ACK_ASSIS_MSG = 1000012
EN_CMD_ID_SESSION_SVR_SESSION_DETAIL = 1000015
EN_CMD_ID_SESSION_SVR_BATCH_SESS_DETAIL = 1000016
EN_CMD_ID_SESSION_SVR_BATCH_RM_SESSIONS = 1000017
BIZ_MSG_TYPE_NORMAL = 0
BIZ_MSG_TYPE_CARD_VIDEO = 1
EN_MSG_SOURCE_UNKONW = 0
EN_MSG_SOURCE_IOS = 1
EN_MSG_SOURCE_ANDRIOD = 2
EN_MSG_SOURCE_H5 = 3
EN_MSG_SOURCE_PC = 4
EN_MSG_SOURCE_BACKSTAGE = 5
EN_MSG_SOURCE_BIZ = 6
EN_MSG_SOURCE_WEB = 7
EN_MSG_SOURCE_AUTOREPLY_BY_FOLLOWED = 8
EN_MSG_SOURCE_AUTOREPLY_BY_RECEIVE_MSG = 9
EN_MSG_SOURCE_AUTOREPLY_BY_KEYWORDS = 10
EN_MSG_SOURCE_AUTOREPLY_BY_VOYAGE = 11
EN_MSG_SOURCE_VC_ATTACH_MSG = 12
EN_INVALID_MSG_TYPE = 0
EN_MSG_TYPE_TEXT = 1
EN_MSG_TYPE_PIC = 2
EN_MSG_TYPE_AUDIO = 3
EN_MSG_TYPE_SHARE = 4
EN_MSG_TYPE_DRAW_BACK = 5
EN_MSG_TYPE_CUSTOM_FACE = 6
EN_MSG_TYPE_SHARE_V2 = 7
EN_MSG_TYPE_SYS_CANCEL = 8
EN_MSG_TYPE_MINI_PROGRAM = 9
EN_MSG_TYPE_NOTIFY_MSG = 10
EN_MSG_TYPE_VIDEO_CARD = 11
EN_MSG_TYPE_ARTICLE_CARD = 12
EN_MSG_TYPE_PICTURE_CARD = 13
EN_MSG_TYPE_COMMON_SHARE_CARD = 14
EN_MSG_TYPE_BIZ_MSG_TYPE = 50
EN_MSG_TYPE_GROUP_MEMBER_CHANGED = 101
EN_MSG_TYPE_GROUP_STATUS_CHANGED = 102
EN_MSG_TYPE_GROUP_DYNAMIC_CHANGED = 103
EN_MSG_TYPE_GROUP_LIST_CHANGED = 104
EM_MSG_TYPE_FRIEND_LIST_CHANGED = 105
EN_MSG_TYPE_GROUP_DETAIL_CHANGED = 106
EN_MSG_TYPE_GROUP_MEMBER_ROLE_CHANGED = 107
EN_MSG_TYPE_NOTICE_WATCH_LIST = 108
EN_MSG_TYPE_NOTIFY_NEW_REPLY_RECIEVED = 109
EN_MSG_TYPE_NOTIFY_NEW_AT_RECIEVED = 110
EN_MSG_TYPE_NOTIFY_NEW_PRAISE_RECIEVED = 111
EN_MSG_TYPE_NOTIFY_NEW_UP_RECIEVED = 112
EN_MSG_TYPE_NOTIFY_NEW_REPLY_RECIEVED_V2 = 113
EN_MSG_TYPE_NOTIFY_NEW_AT_RECIEVED_V2 = 114
EN_MSG_TYPE_NOTIFY_NEW_PRAISE_RECIEVED_V2 = 115
EN_MSG_TYPE_GROUP_DETAIL_CHANGED_MULTI = 116
EN_MSG_TYPE_GROUP_MEMBER_ROLE_CHANGED_MULTI = 117
EN_MSG_TYPE_NOTIFY_ANTI_DISTURB = 118
EN_MSG_TYPE_SYS_GROUP_DISSOLVED = 201
EN_MSG_TYPE_SYS_GROUP_JOINED = 202
EN_MSG_TYPE_SYS_GROUP_MEMBER_EXITED = 203
EN_MSG_TYPE_SYS_GROUP_ADMIN_FIRED = 204
EN_MSG_TYPE_SYS_GROUP_MEMBER_KICKED = 205
EN_MSG_TYPE_SYS_GROUP_ADMIN_KICK_OFF = 206
EN_MSG_TYPE_SYS_GROUP_ADMIN_DUTY = 207
EN_MSG_TYPE_SYS_GROUP_AUTO_CREATED = 208
EN_MSG_TYPE_SYS_FRIEND_APPLY = 210
EN_MSG_TYPE_SYS_FRIEND_APPLY_ACK = 211
EN_MSG_TYPE_SYS_GROUP_APPLY_FOR_JOINING = 212
EN_MSG_TYPE_SYS_GROUP_ADMIN_ACCEPTED_USER_APPLY = 213
EN_MSG_TYPE_CHAT_MEMBER_JOINED = 301
EN_MSG_TYPE_CHAT_MEMBER_EXITED = 302
EN_MSG_TYPE_CHAT_GROUP_FREEZED = 303
EN_MSG_TYPE_CHAT_GROUP_DISSOLVED = 304
EN_MSG_TYPE_CHAT_GROUP_CREATED = 305
EN_MSG_TYPE_CHAT_POPUP_SESSION = 306
EN_NO_MEANING = 0
EN_RECVER_TYPE_PEER = 1
EN_RECVER_TYPE_GROUP = 2
EN_RECVER_TYPE_PEERS = 3
EN_INVALID_LOG_TYPE = 0
EN_ADD_FRIEND = 1
EN_REMOVE_FRIEND = 2
EN_JOIN_GROUP = 3
EN_EXIT_GROUP = 4
INVALID_SESSION_TYPE = 0
UN_FOLD_SESSION = 1
UN_FOLLOW_SINGLE_SESSION = 2
MY_GROUP_SESSION = 3
ALL_SESSION = 4


_ACCOUNTINFO = DESCRIPTOR.message_types_by_name['AccountInfo']
_FRIENDRELATION = DESCRIPTOR.message_types_by_name['FriendRelation']
_GROUPRELATION = DESCRIPTOR.message_types_by_name['GroupRelation']
_HIGHTEXT = DESCRIPTOR.message_types_by_name['HighText']
_IMGINFO = DESCRIPTOR.message_types_by_name['ImgInfo']
_KEYHITINFOS = DESCRIPTOR.message_types_by_name['KeyHitInfos']
_MSG = DESCRIPTOR.message_types_by_name['Msg']
_RELATIONLOG = DESCRIPTOR.message_types_by_name['RelationLog']
_SESSIONINFO = DESCRIPTOR.message_types_by_name['SessionInfo']
AccountInfo = _reflection.GeneratedProtocolMessageType('AccountInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTINFO,
  '__module__' : 'bilibili.im.type.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.type.AccountInfo)
  })
_sym_db.RegisterMessage(AccountInfo)

FriendRelation = _reflection.GeneratedProtocolMessageType('FriendRelation', (_message.Message,), {
  'DESCRIPTOR' : _FRIENDRELATION,
  '__module__' : 'bilibili.im.type.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.type.FriendRelation)
  })
_sym_db.RegisterMessage(FriendRelation)

GroupRelation = _reflection.GeneratedProtocolMessageType('GroupRelation', (_message.Message,), {
  'DESCRIPTOR' : _GROUPRELATION,
  '__module__' : 'bilibili.im.type.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.type.GroupRelation)
  })
_sym_db.RegisterMessage(GroupRelation)

HighText = _reflection.GeneratedProtocolMessageType('HighText', (_message.Message,), {
  'DESCRIPTOR' : _HIGHTEXT,
  '__module__' : 'bilibili.im.type.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.type.HighText)
  })
_sym_db.RegisterMessage(HighText)

ImgInfo = _reflection.GeneratedProtocolMessageType('ImgInfo', (_message.Message,), {
  'DESCRIPTOR' : _IMGINFO,
  '__module__' : 'bilibili.im.type.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.type.ImgInfo)
  })
_sym_db.RegisterMessage(ImgInfo)

KeyHitInfos = _reflection.GeneratedProtocolMessageType('KeyHitInfos', (_message.Message,), {
  'DESCRIPTOR' : _KEYHITINFOS,
  '__module__' : 'bilibili.im.type.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.type.KeyHitInfos)
  })
_sym_db.RegisterMessage(KeyHitInfos)

Msg = _reflection.GeneratedProtocolMessageType('Msg', (_message.Message,), {
  'DESCRIPTOR' : _MSG,
  '__module__' : 'bilibili.im.type.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.type.Msg)
  })
_sym_db.RegisterMessage(Msg)

RelationLog = _reflection.GeneratedProtocolMessageType('RelationLog', (_message.Message,), {
  'DESCRIPTOR' : _RELATIONLOG,
  '__module__' : 'bilibili.im.type.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.type.RelationLog)
  })
_sym_db.RegisterMessage(RelationLog)

SessionInfo = _reflection.GeneratedProtocolMessageType('SessionInfo', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONINFO,
  '__module__' : 'bilibili.im.type.im_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.im.type.SessionInfo)
  })
_sym_db.RegisterMessage(SessionInfo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CMDID._serialized_start=1867
  _CMDID._serialized_end=2655
  _ENUM_BIZ_MSG_TYPE._serialized_start=2657
  _ENUM_BIZ_MSG_TYPE._serialized_end=2730
  _MSGSOURCE._serialized_start=2733
  _MSGSOURCE._serialized_end=3137
  _MSGTYPE._serialized_start=3140
  _MSGTYPE._serialized_end=5039
  _RECVERTYPE._serialized_start=5041
  _RECVERTYPE._serialized_end=5149
  _RELATIONLOGTYPE._serialized_start=5151
  _RELATIONLOGTYPE._serialized_end=5272
  _SESSION_TYPE._serialized_start=5275
  _SESSION_TYPE._serialized_end=5405
  _ACCOUNTINFO._serialized_start=47
  _ACCOUNTINFO._serialized_end=91
  _FRIENDRELATION._serialized_start=93
  _FRIENDRELATION._serialized_end=174
  _GROUPRELATION._serialized_start=177
  _GROUPRELATION._serialized_end=412
  _HIGHTEXT._serialized_start=414
  _HIGHTEXT._serialized_end=467
  _IMGINFO._serialized_start=469
  _IMGINFO._serialized_end=541
  _KEYHITINFOS._serialized_start=543
  _KEYHITINFOS._serialized_end=635
  _MSG._serialized_start=638
  _MSG._serialized_end=1101
  _RELATIONLOG._serialized_start=1104
  _RELATIONLOG._serialized_end=1307
  _SESSIONINFO._serialized_start=1310
  _SESSIONINFO._serialized_end=1864
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/fission/notify.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/broadcast/message/fission/notify.proto\x12\"bilibili.broadcast.message.fission\x1a\x1bgoogle/protobuf/empty.proto\"-\n\x0fGameNotifyReply\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t2f\n\x07\x46ission\x12[\n\nGameNotify\x12\x16.google.protobuf.Empty\x1a\x33.bilibili.broadcast.message.fission.GameNotifyReply0\x01\x62\x06proto3')



_GAMENOTIFYREPLY = DESCRIPTOR.message_types_by_name['GameNotifyReply']
GameNotifyReply = _reflection.GeneratedProtocolMessageType('GameNotifyReply', (_message.Message,), {
  'DESCRIPTOR' : _GAMENOTIFYREPLY,
  '__module__' : 'bilibili.broadcast.message.fission.notify_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.fission.GameNotifyReply)
  })
_sym_db.RegisterMessage(GameNotifyReply)

_FISSION = DESCRIPTOR.services_by_name['Fission']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GAMENOTIFYREPLY._serialized_start=116
  _GAMENOTIFYREPLY._serialized_end=161
  _FISSION._serialized_start=163
  _FISSION._serialized_end=265
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/v1/test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n bilibili/broadcast/v1/test.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\"!\n\tAddParams\x12\t\n\x01\x61\x18\x01 \x01(\x05\x12\t\n\x01\x62\x18\x02 \x01(\x05\"\x16\n\tAddResult\x12\t\n\x01r\x18\x01 \x01(\x05\"c\n\x08TestResp\x12\x0e\n\x06taskid\x18\x01 \x01(\x03\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07message\x18\x03 \x01(\t\x12#\n\x05\x65xtra\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any2S\n\x04Test\x12K\n\x0eWatchTestEvent\x12\x16.google.protobuf.Empty\x1a\x1f.bilibili.broadcast.v1.TestResp0\x01\x32I\n\x05Test2\x12@\n\x04Test\x12 .bilibili.broadcast.v1.AddParams\x1a\x16.google.protobuf.Emptyb\x06proto3')



_ADDPARAMS = DESCRIPTOR.message_types_by_name['AddParams']
_ADDRESULT = DESCRIPTOR.message_types_by_name['AddResult']
_TESTRESP = DESCRIPTOR.message_types_by_name['TestResp']
AddParams = _reflection.GeneratedProtocolMessageType('AddParams', (_message.Message,), {
  'DESCRIPTOR' : _ADDPARAMS,
  '__module__' : 'bilibili.broadcast.v1.test_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.AddParams)
  })
_sym_db.RegisterMessage(AddParams)

AddResult = _reflection.GeneratedProtocolMessageType('AddResult', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESULT,
  '__module__' : 'bilibili.broadcast.v1.test_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.AddResult)
  })
_sym_db.RegisterMessage(AddResult)

TestResp = _reflection.GeneratedProtocolMessageType('TestResp', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESP,
  '__module__' : 'bilibili.broadcast.v1.test_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.TestResp)
  })
_sym_db.RegisterMessage(TestResp)

_TEST = DESCRIPTOR.services_by_name['Test']
_TEST2 = DESCRIPTOR.services_by_name['Test2']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ADDPARAMS._serialized_start=115
  _ADDPARAMS._serialized_end=148
  _ADDRESULT._serialized_start=150
  _ADDRESULT._serialized_end=172
  _TESTRESP._serialized_start=174
  _TESTRESP._serialized_end=273
  _TEST._serialized_start=275
  _TEST._serialized_end=358
  _TEST2._serialized_start=360
  _TEST2._serialized_end=433
# @@protoc_insertion_point(module_scope)



import collections
import time

from .._typing import T_Auth


TOKEN_NAMES = ["access_token", "refresh_token"]


class Auth(collections.UserDict):
    def __init__(self, auth: T_Auth = None, uid: int = 0, expired: int = 0, **kwargs):
        super().__init__()
        self.uid = uid
        self.expired = expired
        self.update(auth)
        self.update(kwargs)

    def get_cookies(self):
        return {
            name: value
            for name, value in self.items()
            if value and name not in TOKEN_NAMES
        }

    def get_tokens(self):
        return {name: self.data[name] for name in TOKEN_NAMES if self.get(name)}

    async def refresh(self):
        from ..login import refresh_token

        resp = await refresh_token(auth=self)
        self.uid = resp["token_info"]["mid"]
        self.expired = resp["token_info"]["expires_in"] + int(time.time())
        self.update(
            {
                name: value
                for name, value in resp["token_info"].items()
                if name in TOKEN_NAMES
            }
        )
        self.update(
            {
                cookie["name"]: cookie["value"]
                for cookie in resp["cookie_info"]["cookies"]
            }
        )
        return self

    async def get_info(self):
        from ..login import get_token_info

        return await get_token_info(self)

    def update(self, auth: T_Auth = None):
        if auth:
            super().update(auth)

    def __getitem__(self, key):
        try:
            return super().__getitem__(key)
        except KeyError:
            return None
